@@ -14,3 +14,6 @@ print instagram.relationship(3403089465)
 print instagram.requested_by()
 print instagram.followed_by()
 print instagram.follows()
+print instagram.locations(514276)
+print instagram.locations_media_recent(514276)
+print instagram.locations_search(37.77493, -122.419415)
